@@ -10,8 +10,7 @@ from django.db.models.functions import Cast
 from django.db.models.lookups import FieldGetDbPrepValueMixin, Lookup, Transform
 from django.utils.translation import gettext_lazy as _
 
-from . import forms
-from .features import features
+from django_jsonfield_backport import forms
 
 __all__ = ["JSONField"]
 
@@ -87,7 +86,7 @@ else:
                 connection = connections[db]
                 if not (
                     "supports_json_field" in self.model._meta.required_db_features
-                    or features[connection.vendor].supports_json_field
+                    or connection.features.supports_json_field
                 ):
                     errors.append(
                         checks.Error(
@@ -109,7 +108,7 @@ else:
         def from_db_value(self, value, expression, connection):
             if value is None:
                 return value
-            if features[connection.vendor].has_native_json_field and self.decoder is None:
+            if connection.features.has_native_json_field and self.decoder is None:
                 return value
             try:
                 return json.loads(value, cls=self.decoder)
@@ -364,14 +363,6 @@ class JSONExact(lookups.Exact):
         return rhs, rhs_params
 
 
-if django.VERSION < (3, 1):
-    JSONField.register_lookup(DataContains)
-    JSONField.register_lookup(ContainedBy)
-    JSONField.register_lookup(HasKey)
-    JSONField.register_lookup(HasKeys)
-    JSONField.register_lookup(HasAnyKeys)
-    JSONField.register_lookup(JSONExact)
-
 if django.VERSION >= (3, 1):
     from django.db.models.fields.json import (
         KeyTextTransform as BuiltinKeyTextTransform,
@@ -603,7 +594,7 @@ class KeyTransformIRegex(CaseInsensitiveMixin, KeyTransformTextLookupMixin, look
 class KeyTransformNumericLookupMixin:
     def process_rhs(self, compiler, connection):
         rhs, rhs_params = super().process_rhs(compiler, connection)
-        if not features[connection.vendor].has_native_json_field:
+        if not connection.features.has_native_json_field:
             rhs_params = [json.loads(value) for value in rhs_params]
         return rhs, rhs_params
 
@@ -624,7 +615,14 @@ class KeyTransformGte(KeyTransformNumericLookupMixin, lookups.GreaterThanOrEqual
     pass
 
 
-if django.VERSION < (3, 1):
+def register_lookups():
+    JSONField.register_lookup(DataContains)
+    JSONField.register_lookup(ContainedBy)
+    JSONField.register_lookup(HasKey)
+    JSONField.register_lookup(HasKeys)
+    JSONField.register_lookup(HasAnyKeys)
+    JSONField.register_lookup(JSONExact)
+
     KeyTransform.register_lookup(KeyTransformExact)
     KeyTransform.register_lookup(KeyTransformIExact)
     KeyTransform.register_lookup(KeyTransformIsNull)
